Crate tlog_tiles

Crate tlog_tiles 

tlog tiles

Implementation of the C2SP tlog-tiles and C2SP checkpoint specifications.

This file contains code ported from the original project tlog.

References:

Re-exports

pub use checkpoint::*;
pub use tile::*;
pub use tlog::*;

Modules

checkpoint
A Checkpoint is a tree head to be formatted according to the C2SP tlog-checkpoint specification.
tile
Provides functionality for a tiled transparency log.
tlog
Provides Merkle Tree functionality required for a basic transparency log.