Checkpoint

Struct Checkpoint 

pub struct Checkpoint { /* private fields */ }
A Checkpoint is a tree head to be formatted according to c2sp.org/checkpoint.

Implementations

Source

impl Checkpoint

pub fn origin(&self) -> &str

Return the checkpoint’s origin.

pub fn size(&self) -> u64

Return the size of the checkpoint’s tree.

pub fn hash(&self) -> &Hash

Return the root hash of the checkpoint’s tree.

pub fn extension(&self) -> &str

Return the checkpoint’s extensions.

pub fn new( origin: &str, size: u64, hash: Hash, extension: &str, ) -> Result<Self, MalformedCheckpointError>

Return a new checkpoint with the given arguments.

Errors

Returns a MalformedCheckpointError if the arguments do not comply with the C2SP tlog-checkpoint specification.

pub fn from_bytes(text: &[u8]) -> Result<Self, MalformedCheckpointError>

Parse a checkpoint from encoded bytes.

Errors

Returns an error if the checkpoint is malformed.

pub fn from_reader<R: BufRead>( reader: &mut R, strict: bool, ) -> Result<Self, MalformedCheckpointError>

Parse a checkpoint from encoded bytes reader. If strict is set to true, the reader should exactly match a checkpoint. Otherwise, read until we encounter a blank line (only a newline).

Errors

Returns an error if the checkpoint is malformed.

pub fn to_bytes(&self) -> Vec<u8>

Returns an encoded checkpoint.